import { defineComponent, computed, openBlock, createElementBlock, createElementVNode, normalizeClass, normalizeStyle, toDisplayString, createCommentVNode } from 'vue';

var script = /*#__PURE__*/defineComponent({
  name: "RadialProgressVue3",
  props: {
    width: {
      type: Number,
      default: 80
    },
    strokeWidth: {
      type: Number,
      default: 6
    },
    strokeColor: {
      type: String,
      default: "#2e5090"
    },
    innerStrokeColor: {
      type: String,
      default: "#ffaadd"
    },
    fillColor: {
      type: String,
      default: "#E6E6FA"
    },
    roundedStroke: {
      type: Boolean,
      default: false
    },
    showText: {
      type: Boolean,
      default: true
    },
    textColor: {
      type: String,
      default: "#222222"
    },
    fontWeight: {
      type: [String, Number],
      default: 900
    },
    fontSize: {
      type: Number,
      default: 12
    },
    showPercentSymbol: {
      type: Boolean,
      default: true
    },
    clockWise: {
      type: Boolean,
      default: true
    },
    percent: {
      type: Number,
      default: 42
    }
  },
  setup: props => {
    const radius = props.width / 2 - props.strokeWidth * 2;
    const circumference = 2 * Math.PI * radius;
    const offset = computed(() => {
      if (props.clockWise) {
        return circumference - props.percent / 100 * circumference;
      } else {
        return circumference + props.percent / 100 * circumference;
      }
    });
    const roundedPercent = computed(() => Math.round(props.percent));
    return {
      radius,
      circumference,
      offset,
      roundedPercent
    };
  }
});

const _hoisted_1 = ["width", "height"];
const _hoisted_2 = ["cx", "cy", "r", "fill", "stroke", "stroke-width"];
const _hoisted_3 = ["cx", "cy", "r", "stroke", "stroke-width", "stroke-dasharray", "stroke-dashoffset", "stroke-linecap"];
const _hoisted_4 = ["fill"];
function render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", {
    width: _ctx.width,
    height: _ctx.width
  }, [createElementVNode("circle", {
    cx: _ctx.width / 2,
    cy: _ctx.width / 2,
    r: _ctx.radius,
    fill: _ctx.fillColor,
    stroke: _ctx.innerStrokeColor,
    "stroke-width": _ctx.strokeWidth
  }, null, 8, _hoisted_2), createElementVNode("circle", {
    cx: _ctx.width / 2,
    cy: _ctx.width / 2,
    r: _ctx.radius,
    fill: "transparent",
    stroke: _ctx.strokeColor,
    "stroke-width": _ctx.strokeWidth,
    "stroke-dasharray": _ctx.circumference,
    "stroke-dashoffset": _ctx.offset,
    "stroke-linecap": _ctx.roundedStroke ? 'round' : 'butt',
    class: normalizeClass(_ctx.$style.circle)
  }, null, 10, _hoisted_3), _ctx.showText ? (openBlock(), createElementBlock("text", {
    key: 0,
    x: "50%",
    y: "50%",
    fill: _ctx.textColor,
    style: normalizeStyle({
      fontWeight: _ctx.fontWeight,
      fontSize: `${_ctx.fontSize}px`
    }),
    "dominant-baseline": "middle",
    "text-anchor": "middle"
  }, toDisplayString(_ctx.roundedPercent) + toDisplayString(_ctx.showPercentSymbol ? "%" : ""), 13, _hoisted_4)) : createCommentVNode("", true)], 8, _hoisted_1);
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "\n._circle_2cw8x_2 {\n  transform: rotate(-90deg);\n  transform-origin: center;\n\n  transition: 500ms stroke-dashoffset linear;\n}\n";
styleInject(css_248z);

var style0 = {
  "circle": "_circle_2cw8x_2"
};

const cssModules = script.__cssModules = {};
cssModules["$style"] = style0;
script.render = render;

// Import vue component
// IIFE injects install function into component, allowing component
// to be registered via Vue.use() as well as Vue.component(),

var entry_esm = /*#__PURE__*/(() => {
  // Assign InstallableComponent type
  const installable = script; // Attach install function executed by Vue.use()

  installable.install = app => {
    app.component('RadialProgressVue3', installable);
  };

  return installable;
})(); // It's possible to expose named exports when writing components that can
// also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
// export const RollupDemoDirective = directive;

export { entry_esm as default };
